@@ -3,22 +3,30 @@ package MyApp::Service::Calculator;
 use strict;
 use warnings;
 
-use Beekeeper::Worker;
+use Beekeeper::Worker ':log';
 use base 'Beekeeper::Worker';
 
 
+sub authorize_request {
+    my ($self, $req) = @_;
+
+    return BKPR_REQUEST_AUTHORIZED;
+}
+
 sub on_startup {
     my $self = shift;
 
     $self->accept_remote_calls(
         'myapp.calculator.eval_expr' => 'eval_expr',
     );
+
+    log_info "Ready";
 }
 
-sub authorize_request {
-    my ($self, $req) = @_;
+sub on_shutdown {
+    my $self = shift;
 
-    return BKPR_REQUEST_AUTHORIZED;
+    log_info "Stopped";
 }
 
 sub eval_expr {
