@@ -3,7 +3,7 @@ package Beekeeper;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 1;
 
@@ -19,7 +19,7 @@ Beekeeper - Framework for building applications with a microservices architectur
  
 =head1 VERSION
  
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
@@ -148,6 +148,8 @@ B<What does this framework provides:>
 
 - Performance metrics gathering, which can be shoveled to an external monitoring application.
 
+- A nice HTML dashboard, which can be used in any project.
+
 
 =head1 Getting Started
 
@@ -307,6 +309,8 @@ C<examples/websocket> uses a service from a browser using WebSockets.
 
 C<examples/chat> implements a real world setup with isolated buses and redundancy.
 
+C<examples/dashboard> is an HTML dashboard for Beekeeper projects.
+
 
 =head1 SEE ALSO
 
