@@ -3,25 +3,23 @@ package Beekeeper::Service::Supervisor;
 use strict;
 use warnings;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Beekeeper::Client;
 
+# Show errors from perspective of caller
+$Carp::Internal{(__PACKAGE__)}++;
+
 
 sub restart_pool {
     my ($class, %args) = @_;
 
     my $client = Beekeeper::Client->instance;
-
     my $guard = $client->__use_authorization_token('BKPR_ADMIN');
 
     $client->send_notification(
         method => '_bkpr.supervisor.restart_pool',
-        params => {
-            host  => $args{'host'},
-            pool  => $args{'pool'},
-            delay => $args{'delay'},
-        },
+        params => \%args,
     );
 }
 
@@ -29,17 +27,11 @@ sub restart_workers {
     my ($class, %args) = @_;
 
     my $client = Beekeeper::Client->instance;
-
     my $guard = $client->__use_authorization_token('BKPR_ADMIN');
 
     $client->send_notification(
         method => '_bkpr.supervisor.restart_workers',
-        params => {
-            host  => $args{'host'},
-            pool  => $args{'pool'},
-            class => $args{'class'},
-            delay => $args{'delay'},
-        },
+        params => \%args,
     );
 }
 
@@ -47,42 +39,82 @@ sub get_workers_status {
     my ($class, %args) = @_;
 
     my $client = Beekeeper::Client->instance;
-
     my $guard = $client->__use_authorization_token('BKPR_ADMIN');
+    my $timeout = delete $args{'timeout'};
 
     my $resp = $client->call_remote(
         method  => '_bkpr.supervisor.get_workers_status',
-        timeout => $args{'timeout'},
-        params  => {
-            host  => $args{'host'},
-            pool  => $args{'pool'},
-            class => $args{'class'},
-        },
+        params  => \%args,
+        timeout => $timeout,
     );
 
     return $resp->result;
 }
 
+sub get_workers_status_async {
+    my ($class, %args) = @_;
+
+    my $on_success = delete $args{'on_success'};
+    my $on_error   = delete $args{'on_error'};
+
+    unless ($on_error) {
+        my ($file, $line) = (caller)[1,2];
+        $on_error = sub { die $_[0]->message . " at $file line $line\n"; };
+    }
+
+    my $client = Beekeeper::Client->instance;
+    my $guard = $client->__use_authorization_token('BKPR_ADMIN');
+    my $timeout = delete $args{'timeout'};
+
+    $client->call_remote_async(
+        method     => '_bkpr.supervisor.get_workers_status',
+        params     => \%args,
+        timeout    => $timeout,
+        on_success => $on_success,
+        on_error   => $on_error,
+    );
+}
+
 sub get_services_status {
     my ($class, %args) = @_;
 
     my $client = Beekeeper::Client->instance;
-
     my $guard = $client->__use_authorization_token('BKPR_ADMIN');
+    my $timeout = delete $args{'timeout'};
 
     my $resp = $client->call_remote(
         method  => '_bkpr.supervisor.get_services_status',
-        timeout => $args{'timeout'},
-        params  => {
-            host  => $args{'host'},
-            pool  => $args{'pool'},
-            class => $args{'class'},
-        },
+        params  => \%args,
+        timeout => $timeout,
     );
 
     return $resp->result;
 }
 
+sub get_services_status_async {
+    my ($class, %args) = @_;
+
+    my $on_success = delete $args{'on_success'};
+    my $on_error   = delete $args{'on_error'};
+
+    unless ($on_error) {
+        my ($file, $line) = (caller)[1,2];
+        $on_error = sub { die $_[0]->message . " at $file line $line\n"; };
+    }
+
+    my $client = Beekeeper::Client->instance;
+    my $guard = $client->__use_authorization_token('BKPR_ADMIN');
+    my $timeout = delete $args{'timeout'};
+
+    $client->call_remote_async(
+        method     => '_bkpr.supervisor.get_services_status',
+        params     => \%args,
+        timeout    => $timeout,
+        on_success => $on_success,
+        on_error   => $on_error,
+    );
+}
+
 1;
 
 __END__
@@ -97,10 +129,29 @@ Beekeeper::Service::Supervisor - Worker pool supervisor
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 SYNOPSIS
 
+  my $status = Beekeeper::Service::Supervisor->get_services_status(
+      host => '.*',
+      pool => '.*',
+      pool => '.*',
+  );
+  
+  print "$_: $status->{$_}->{load}\n" foreach keys %$status;
+  
+  Beekeeper::Service::Supervisor->get_services_status(
+      on_success => sub {
+          my ($status) = @_;
+          print "$_: $status->{$_}->{load}\n" foreach keys %$status;
+      },
+      on_error => sub {
+          my ($error) = @_;
+          die $error->message;
+      },
+  );
+
 =head1 DESCRIPTION
 
 A Supervisor worker is created automatically in every worker pool.
@@ -161,6 +212,17 @@ Returns the individual performance metrics of every worker of all active service
 
 Services can be filtered by C<host>, C<pool> and  C<class>.
 
+=head3 get_services_status_async ( %filters, on_success => $cb, on_error => $cb )
+
+Asynchronous version of C<get_services_status> method.
+
+Callbacks C<on_success> and C<on_error> must be coderefs and will receive respectively 
+L<Beekeeper::JSONRPC::Response> and L<Beekeeper::JSONRPC::Error> objects as arguments.
+
+=head3 get_workers_status_async ( %filters, on_success => $cb, on_error => $cb )
+
+Asynchronous version of C<get_workers_status> method.
+
 =head1 SEE ALSO
  
 L<bkpr-top>, L<bkpr-restart>, L<Beekeeper::Service::Supervisor::Worker>.
